<template>
<div class="devErrorLine1Container fl">
  <h4>年度设备故障数统计</h4>
  <div class="chartBox">
    <echarts chart-id="devErrorLine1" :chart-option="options"></echarts>
  </div>
</div>
</template>

<script>
import * as echarts from 'echarts'
export default {
  name: 'devErrorLine1',
  components: {},
  props: {
    selected: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      options: {
        grid: {
          top: "10%",
          left: '25%',
          right: '0',
          bottom: "16%"
        },
        tooltip: {
          trigger: "axis",
          axisPointer: {
            type: "shadow",
            label: {
              show: true
            }
          }
        },
        xAxis: {
          boundaryGap: false,
          data: [
            "1月",
            "2月",
            "3月",
            "4月",
            "5月",
            "6月",
            "7月",
            "8月",
            "9月",
            "10月",
            "11月",
            "12月"
          ],
          splitLine: {
            show: true,
            interval: 0,
            lineStyle: {
              color: 'rgba(250,250,250,0.2)',
              type: 'dashed'
            }
          },
          axisLine: {
            show: true, //隐藏X轴轴线
            lineStyle: {
              color: 'rgba(250,250,250,0.4)',
              width: 1
            }
          },
          axisTick: {
            show: false //隐藏X轴刻度
          },
          axisLabel: {
            show: true,
            interval: 1,
            textStyle: {
              color: "rgba(250,250,250,0.6)", //X轴文字颜色
              fontSize: 12
            }
          },
          splitArea: {
            show: true,
            interval: 0,
            areaStyle: {
              color: ["rgba(30, 47, 66, 0.35)", "rgba(250,250,250,0)"]
            }
          }
        },
        yAxis: {
          type: "value",
          splitLine: {
            show: true,
            lineStyle: {
              color: 'rgba(250,250,250,0.2)',
              type: 'dashed'
            }
          },
          splitNumber: 3,
          axisTick: {
            show: false
          },
          axisLine: {
            show: false
          },
          axisLabel: {
            show: true,
            textStyle: {
              color: "rgba(250,250,250,0.6)",
              fontSize: 12
            }
          },
        },
        series: [{
          name: "",
          type: "line",
          smooth: true, //平滑曲线显示
          showAllSymbol: true, //显示所有图形。
          symbol: "none", //标记的图形为实心圆
          lineStyle: {
            color: "rgba(141, 140, 140, 1)",
            width: 2
          },
          areaStyle: {
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
                offset: 0,
                color: "rgba(141, 140, 140, .8)"
              },
              {
                offset: 1,
                color: "rgba(141, 140, 140, 0)"
              }
            ])
          },
          data: []
        }]
      }
    }
  },
  watch: {
    selected(newV) {
      this.initChart(newV)
    }
  },
  mounted() {
   
    this.$nextTick(() => {
      this.initChart(this.selected)
    })
  },
  methods: {
    initChart(data) {
      let seriesData = []
      switch (data) {
        case 'thermal':
          seriesData = [9, 43, 11, 9, 47, 37, 15, 16, 14, 25, 5, 26]
          break;
        case 'waterSupply':
          seriesData = [24, 84, 39, 34, 92, 76, 58, 46, 44, 25, 58, 134]
          break;
        case 'gas':
          seriesData = [11, 54, 21, 11, 39, 23, 28, 17, 41, 54, 83, 108]
          break;
        case 'integrated':
          seriesData = [208, 532, 203, 185, 501, 465, 271, 258, 203, 363, 360, 676]
          break;
        case 'waterlogging':
          seriesData = [67, 167, 44, 48, 101, 161, 111, 43, 35, 88, 103, 173]
          break;
        case 'fire':
          seriesData = [32, 87, 21, 31, 49, 51, 28, 81, 40, 56, 31, 87]
          break;
        case 'pipeRack':
          seriesData = [65, 97, 67, 52, 173, 117, 31, 55, 29, 115, 80, 148]
          break;
        default:
          break;
      }
      this.options.series[0].data = [...seriesData]
    }
  }
}
</script>

<style lang="scss" scoped>
.devErrorLine1Container {
  height: 100%;
  width: 30%;

  h4 {
    height: 26px;
    line-height: 12px;
    font-size: 12px;
    font-weight: bold;
    color: rgba(141, 140, 140, 1);
    text-align: center;
  }

  .chartBox {
    height: calc(100% - 26px);
  }
}
</style>
